package com.ruoyi.generator.service;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.generator.domain.Community.CommunityArticle;
import com.ruoyi.generator.domain.Community.CommunityArticleCollect;
import com.ruoyi.generator.domain.Community.CommunityLike;
import com.ruoyi.generator.mapper.community.CommunityArticleMapper;
import com.ruoyi.generator.vo.CommunityArticleCommentVo;
import com.ruoyi.generator.vo.CommunityArticleVo;
import com.ruoyi.system.mapper.SysUserMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;

/**
 * 业务 服务层实现
 *
 * @author ruoyi
 */
@Service
public class CommunityArticleServiceImpl implements ICommunityArticleService {
    private static final Logger log = LoggerFactory.getLogger(CommunityArticleServiceImpl.class);

    @Autowired
    private CommunityArticleMapper communityArticleMapper;

    @Autowired
    private SysUserMapper sysUserMapper;

    /**
     * 查询文章列表
     *
     * @param communityArticle 文章信息
     * @return 文章信息集合
     */
    @Override
    public List<CommunityArticleVo> selectCommunityArticleList(CommunityArticle communityArticle) {
        List<CommunityArticleVo> communityArticleVos = communityArticleMapper.selectCommunityArticleList(communityArticle);
        CommunityArticleVo communityArticleVo = null;
        Long userId = SecurityUtils.getUserId();
        for (int i = 0; i < communityArticleVos.size(); i++) {
            communityArticleVo = communityArticleVos.get(i);
            //文章下的评论
            List<CommunityArticleCommentVo> comments = communityArticleVo.getComments();
            for (CommunityArticleCommentVo communityArticleCommentVo : comments) {
                //获取评论的用户信息
                SysUser sysUser = sysUserMapper.selectUserById(communityArticleCommentVo.getUserId());
                communityArticleCommentVo.setUsername(sysUser.getUserName());
                communityArticleCommentVo.setAvatar(sysUser.getAvatar());

                //判断是否已收藏
                CommunityArticleCollect collect = communityArticleMapper.selectCommunityArticleCollectById(userId, communityArticleCommentVo.getArticleId());
                communityArticleVo.setCollect(!Objects.isNull(collect));

                //判断是否已点赞
                CommunityLike like = communityArticleMapper.selectCommunityArticleLikeById(userId, communityArticleCommentVo.getArticleId());
                communityArticleVo.setLike(!Objects.isNull(like));
            }
        }
        return communityArticleVos;
    }
}